.. -*- rst -*- 

Authors & Acknowledgements
========================== 
Neuroarch was developed by

* `Lev Givon <http://lebedov.github.io>`_
* `Nikul H. Ukani <http://www.linkedin.com/pub/nikul-ukani/16/737/990>`_
* `Yiyin Zhou <http://www.bionet.ee.columbia.edu/people>`_

Other contributors include:

* `Allison Fenichel <https://www.linkedin.com/in/afenichel>`_
